==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Navigation/DefaultNavigation/ts/DefaultNavigation_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>DefaultNavigation</name>
    <message>
        <location filename="../DefaultNavigation.js" line="+46"/>
        <source>Graphics View</source>
        <translation>Grafische weergave</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Navigation</source>
        <translation>Navigatie</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Zoom (Wheel Mouse)</source>
        <translation>Zoom (wielmuis)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Scroll (Trackpad, Multi-Touch Mouse)</source>
        <translation>Scrollen (trackpad, multi-touch muis)</translation>
    </message>
</context>
<context>
    <name>GraphicsViewNavigation</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Mouse wheel / two finger swipe:</source>
        <translation>Muiswiel / twee vingerbeweging:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Enable pan gesture</source>
        <translation>Gebaar om te verplaatsen inschakelen</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Reverse mouse wheel direction for zoom</source>
        <translation>Muiswiel richting voor zoomen omkeren</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Mouse wheel zoom factor:</source>
        <translation>Muiswiel vergrotingsfactor:</translation>
    </message>
    <message>
        <location line="-34"/>
        <source>Limit zoom and scroll to prevent overflows</source>
        <translation>Zoomen en scrollen beperken om overflows te voorkomen</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Navigation/DefaultNavigation/ts/DefaultNavigation_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>DefaultNavigation</name>
    <message>
        <location filename="../DefaultNavigation.js" line="+47"/>
        <source>Graphics View</source>
        <translation>Grafische weergave</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Navigation</source>
        <translation>Navigatie</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Zoom (Wheel Mouse)</source>
        <translation>Zoom (wielmuis)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Scroll (Trackpad, Multi-Touch Mouse)</source>
        <translation>Scrollen (trackpad, multi-touch muis)</translation>
    </message>
</context>
<context>
    <name>GraphicsViewNavigation</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Mouse wheel / two finger swipe:</source>
        <translation>Muiswiel / twee vingerbeweging:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Enable pan gesture</source>
        <translation>Gebaar om te verplaatsen inschakelen</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Reverse mouse wheel direction for zoom</source>
        <translation>Muiswiel richting voor zoomen omkeren</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Middle mouse button zoom factor:</source>
        <translation>Middelste muisknop vergrotingsfactor:</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Mouse wheel zoom factor:</source>
        <translation>Muiswiel vergrotingsfactor:</translation>
    </message>
    <message>
        <location line="+207"/>
        <source>Panning threshold (px):</source>
        <translation>Drempelwaarde voor panning (pixel):</translation>
    </message>
    <message>
        <location line="-217"/>
        <source>Limit zoom and scroll to prevent overflows</source>
        <translation>Zoomen en scrollen beperken om overflows te voorkomen</translation>
    </message>
</context>
</TS>
